    REM Coil Winder Control Program V2.0
    REM Terry Fritz   10-9-97
    COLOR 14, 1, 2
    CLS
    PRINT
    PRINT "Coil Winder Control Program V2.0"
    PRINT
    INPUT "Length of Coil (inches) "; CoilLength
    INPUT "Diameter of Coil (inches) "; CoilDiameter
    INPUT "Number of Turns "; TotalTurns
    INPUT "Wire Diameter (inches) "; WireDiameter
    INPUT "Wind Type (0=Linear, 1=Voltage, 2=Capacitance) "; WindType
    INPUT "Serial Port (1 / 2) "; ComPort$
    PRINT
    PRINT "Calculating Data"
   
    REM Computer Setup
    BaudRate$ = "600"
    BufferSize$ = "2"
                  
    REM Winder Setup
    DrumRPM = 10
    ScrewPitch = 13
    TurnPerStep = 7.5 / 360
   
    REM Coil Calculations
    WireLength = 3.14159 * CoilDiameter * TotalTurns / 12
    PercentWire = (TotalTurns * WireDiameter) / CoilLength * 100
    PulseDistance = TurnPerStep / ScrewPitch

    REM Coil Spacing Calculatios
    DIM Voltage(TotalTurns), TurnVoltage(TotalTurns), CapacitanceFactor(TotalTurns), Spacing(TotalTurns), Total(TotalTurns)
    FOR x = 1 TO TotalTurns
    Voltage(x) = SIN(x * 3.14159 / (2 * TotalTurns))
    TurnVoltage(x) = Voltage(x) - Voltage(x - 1)
    CapacitanceFactor(x) = TurnVoltage(x) ^ WindType
    TotalCapacitanceFactor = TotalCapacitanceFactor + CapacitanceFactor(x)
    NEXT x

    REM Winding Calculations
    FOR x = 1 TO TotalTurns
    Spacing(x) = WireDiameter + (100 - PercentWire) / 100 * CoilLength * (CapacitanceFactor(x) / TotalCapacitanceFactor)
    Total(x) = Total(x - 1) + Spacing(x)
    NEXT x

    REM Wind Coil
    q$ = "COM" + ComPort$ + ":" + BaudRate$ + ",n,8,1,CS0,DS0,CD0,OP0,RB256,TB" + BufferSize$
    OPEN q$ FOR OUTPUT AS #1
    CLS
    PRINT
    PRINT "Coil Diameter "; CoilDiameter; " inches"
    PRINT "Coil Length "; CoilLength; " inches"
    PRINT "Coil Turns "; TotalTurns
    PRINT "Wire Diameter "; WireDiameter; " inches"
    IF WindType = 0 THEN PRINT "Linear Wind"
    IF WindType = 1 THEN PRINT "Linear Voltage Wind"
    IF WindType = 2 THEN PRINT "Linear Capacitance Wind"
    PRINT "Length of Wire (feet) "; USING "#####.#"; WireLength
    PRINT

    INPUT "Begin Wind (y/n)"; q$: IF q$ <> "y" THEN 2000
     
    REM Wind the Coil
   
    REM Pre Wind
    SLEEP 5
    FOR z = 1 TO .5 / PulseDistance
    PRINT #1, CHR$(240);
    NEXT z
   
    REM Winding Loop
    Travel = 0
    StartTime = TIMER
500 LOCATE 12, 1
    PresentTime = TIMER - StartTime
    StepNumber = PresentTime / 60 * DrumRPM
    IF StepNumber >= TotalTurns GOTO 1000
    PRINT " Travel (inches) "; USING "##.###"; Travel
    PRINT " Pitch (inches) "; USING "##.####"; Spacing(StepNumber)
    Place = Total(INT(StepNumber + 1)) - Total(INT(StepNumber))
    Place = Place * (StepNumber - INT(StepNumber)) + Total(INT(StepNumber))
    PRINT " Wire Used (feet) "; USING "####.#"; StepNumber * 3.14159 * CoilDiameter / 12
    IF Place > Travel THEN Travel = Travel + PulseDistance: PRINT #1, CHR$(240); : PulseNumber = PulseNumber + 1
    PRINT " Turn Number "; USING "####.#"; StepNumber
    PRINT " Pulse Number "; USING "######"; PulseNumber
    PRINT " Position Error (mil) "; USING "#####"; (Travel - Place) * 1000
    PRINT " Remaining Time (min) "; USING "####.##"; TotalTurns / DrumRPM - PresentTime / 60
GOTO 500
   
1000 REM End Program
     FOR z = 1 TO .5 / PulseDistance
     PRINT #1, CHR$(240);
     NEXT z
     SLEEP 5

2000 CLOSE #1
     LOCATE 21, 1
     END





